
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-08-20T17:23:20-0500",
 "dirty": false,
 "error": null,
 "full-revisionid": "170fa827bc1f1f1189cabc9a04a54842064c5e4c",
 "version": "3.13.0"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
